@@ -10,6 +10,11 @@ summary.hlme <- function(object,...){
       cat("Heterogenous linear mixed model", "\n")
     }
     cat("     fitted by maximum likelihood method", "\n")
+    if(inherits(x, "externVar")){
+      if(x$varest == "none") cat(" ** Parameter variance estimated without correction for primary model uncertainty **", "\n \n")
+      if(x$varest == "Hessian") cat(" ** Total parameter variance estimated using the Hessian of the joint likelihood **", "\n \n")
+      if(x$varest == "paramBoot") cat(" ** Total parameter variance estimated using parametric bootstrap **", "\n \n")
+    }
 
     cl <- x$call
     cl$B <- NULL
@@ -303,8 +308,7 @@ summary.hlme <- function(object,...){
             if(any(c(NPROB+NEF+NVC+1:(NW+ncor+1)) %in% posfix)) maxch[1] <- maxch[1]-1
             colnames(std) <- c(paste(paste(rep(" ",max(maxch[1]-4,0)),collapse=""),"coef",sep=""),
                                paste(paste(rep(" ",max(maxch[2]-2,0)),collapse=""),"Se",sep=""))
-            if(inherits(x, "externVar")) colnames(std)[2] = paste(paste(rep(" ",max(maxch[2]-4,0)),collapse=""),"Se**",sep="")
-            
+ 
             print(std,quote=FALSE,na.print="")
             cat("\n")
 
@@ -312,11 +316,6 @@ summary.hlme <- function(object,...){
                 {
                     cat(" * coefficient fixed by the user \n \n")
                 }
-            if(inherits(x, "externVar")){
-              if(x$varest == "none") cat(" ** total variance estimated witout correction for primary model uncertainty", "\n \n")
-              if(x$varest == "Hessian") cat(" ** total variance estimated through the Hessian of the joint likelihood", "\n \n")
-              if(x$varest == "paramBoot") cat(" ** total variance estimated through parametric bootstrap", "\n \n")
-            }
               
             return(invisible(tTable))
         }
