@@ -1,5 +1,5 @@
 #' Summary of a \code{hlme}, \code{lcmm}, \code{Jointlcmm}, \code{multlcmm},
-#' \code{mpjlcmm}, \code{externSurv}, \code{externX},
+#' \code{mpjlcmm}, \code{externSurv}, \code{externX}
 #' \code{epoce} or \code{Diffepoce} objects
 #' 
 #' The function provides a summary of \code{hlme}, \code{lcmm}, \code{multlcmm}
@@ -39,6 +39,11 @@ summary.lcmm <- function(object,...)
       cat("General latent class mixed model", "\n")
     }
     cat("     fitted by maximum likelihood method", "\n")
+    if(inherits(x, "externVar")){
+      if(x$varest == "none") cat(" ** Parameter variance estimated without correction for primary model uncertainty **", "\n \n")
+      if(x$varest == "Hessian") cat(" ** Total parameter variance estimated using the Hessian of the joint likelihood **", "\n \n")
+      if(x$varest == "paramBoot") cat(" ** Total parameter variance estimated using parametric bootstrap **", "\n \n")
+    }
     
     cl <- x$call
     cl$B <- NULL
@@ -412,7 +417,6 @@ summary.lcmm <- function(object,...)
                            paste(paste(rep(" ",max(maxch[2]-2,0)),collapse=""),"Se",sep=""),
                            paste(paste(rep(" ",max(maxch[3]-4,0)),collapse=""),"Wald",sep=""),
                            paste(paste(rep(" ",max(maxch[4]-7,0)),collapse=""),"p-value",sep=""))
-        if(inherits(x, "externVar")) colnames(tmp)[2] = paste(paste(rep(" ",max(maxch[2]-4,0)),collapse=""),"Se**",sep="")
         cat("\n")
         print(tmp,quote=FALSE,na.print="")
         cat("\n")
@@ -421,12 +425,7 @@ summary.lcmm <- function(object,...)
             {
                 cat(" * coefficient fixed by the user \n \n")
             }
-        if(inherits(x, "externVar")){
-          if(x$varest == "none") cat(" ** total variance estimated witout correction for primary model uncertainty", "\n \n")
-          if(x$varest == "Hessian") cat(" ** total variance estimated through the Hessian of the joint likelihood", "\n \n")
-          if(x$varest == "paramBoot") cat(" ** total variance estimated through parametric bootstrap", "\n \n")
-        }
-        
+
         return(invisible(tTable))
     }
 }
